Class {
	#name : #MiniDocs,
	#superclass : #Object,
	#category : #MiniDocs
}

{ #category : #accessing }
MiniDocs class >> appFolder [
	| tempFolder userDataFolder |
	userDataFolder := Smalltalk os isWindows
		ifTrue: [ FileLocator home / 'AppData' / 'Local' ] 
		ifFalse: [ FileLocator userData ].
	tempFolder := userDataFolder / 'Mutabit' / 'MiniDocs'.	
	tempFolder exists ifFalse: [ tempFolder ensureCreateDirectory ].
	^ tempFolder 
]

{ #category : #accessing }
MiniDocs class >> installYamlToJson [
	"For the moment, only Gnu/Linux and Mac are supported.
	IMPORTANT: Nimble, Nim's package manager should be installed, as this process doesn't verify its proper installation."
	self yamlToJsonBinary exists ifTrue: [ ^ MiniDocs appFolder ].
	Nimble install: 'commandeer'.
	OSSUnixSubprocess new
		command: 'nim';
		arguments: {'c'. self yamlToJsonSourceCode fullName};
		runAndWaitOnExitDo: [ :process :outString |
			(self yamlToJsonSourceCode parent / self yamlToJsonSourceCode basenameWithoutExtension) moveTo: MiniDocs appFolder asFileReference.
			^ MiniDocs appFolder ]
]

{ #category : #accessing }
MiniDocs class >> yamlToJson: yamlString [
	"This method uses a external binary written in Nim, as the native Pharo parser for YAML, written in PetitParser,
	was less robust and unable to parse correctly the same strings as the external one."
	self yamlToJsonBinary exists ifFalse: [ self installYamlToJson ].
	
	OSSUnixSubprocess new 
		command: self yamlToJsonBinary fullName;
		arguments: {yamlString};
		redirectStdout;
		runAndWaitOnExitDo: [ :process :outString  | 
			^ (STONJSON fromString: outString allButFirst) first 
		]
]

{ #category : #accessing }
MiniDocs class >> yamlToJsonBinary [
	^ self appFolder  / 'yamlToJson'
]

{ #category : #accessing }
MiniDocs class >> yamlToJsonSourceCode [
 ^ FileLocator image parent / 'pharo-local/iceberg/Offray/MiniDocs/src/yamlToJson.nim'
]
